@@ -1,16 +1,4 @@
 # Copyright 1999-2000 by Roger S. Bivand
-#
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-
 #
 #
 # plot.grassmeta provides a simple interface between grass data
@@ -32,7 +20,7 @@ plot.grassmeta <- function(x, layer=NULL, xlab="", ylab="",
 	    stop("GRASS object metadata do not match layer length")
         if (is.null(reverse)) reverse <- reverse(G)
 	    image(x=G$xseq, y=G$yseq, z=t(matrix(layer[reverse],
-            nrow=G$Nrow, ncol=G$Ncol, byrow=T)), add=T, ...)
+            nrow=G$Nrow, ncol=G$Ncol, byrow=TRUE)), add=TRUE, ...)
 	}
 }
 
